macro_rules! mmf_mut {
($float:ident) => { ... };
}Expand description
Decrements the provided floating point number by one and returns it.
macro_rules! mmf_mut {
($float:ident) => { ... };
}Decrements the provided floating point number by one and returns it.