pub fn cargo_pkg_version_pre_pair() -> (&'static str, &'static str)Expand description
Fetches the value associated with the CARGO_PKG_VERSION_PRE environment variable. Returns a tuple with the name of the environment variable used in the first position and the value retrieved in the second position.